#ifndef NT2_INCLUDE_FUNCTIONS_COMPARE_LESS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COMPARE_LESS_HPP_INCLUDED

#include <nt2/reduction/include/functions/compare_less.hpp>

#endif
